@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Docstring checker from the basic checker."""
 
@@ -59,21 +59,21 @@ class DocStringChecker(_BasicChecker):
         "C0114": (
             "Missing module docstring",
             "missing-module-docstring",
-            "Used when a module has no docstring."
+            "Used when a module has no docstring. "
             "Empty modules do not require a docstring.",
             {"old_names": [("C0111", "missing-docstring")]},
         ),
         "C0115": (
             "Missing class docstring",
             "missing-class-docstring",
-            "Used when a class has no docstring."
+            "Used when a class has no docstring. "
             "Even an empty class must have a docstring.",
             {"old_names": [("C0111", "missing-docstring")]},
         ),
         "C0116": (
             "Missing function or method docstring",
             "missing-function-docstring",
-            "Used when a function or method has no docstring."
+            "Used when a function or method has no docstring. "
             "Some special methods like __init__ do not require a "
             "docstring.",
             {"old_names": [("C0111", "missing-docstring")]},
@@ -108,16 +108,16 @@ class DocStringChecker(_BasicChecker):
     def open(self) -> None:
         self.linter.stats.reset_undocumented()
 
-    @utils.only_required_for_messages("missing-docstring", "empty-docstring")
+    @utils.only_required_for_messages("missing-module-docstring", "empty-docstring")
     def visit_module(self, node: nodes.Module) -> None:
         self._check_docstring("module", node)
 
-    @utils.only_required_for_messages("missing-docstring", "empty-docstring")
+    @utils.only_required_for_messages("missing-class-docstring", "empty-docstring")
     def visit_classdef(self, node: nodes.ClassDef) -> None:
         if self.linter.config.no_docstring_rgx.match(node.name) is None:
             self._check_docstring("class", node)
 
-    @utils.only_required_for_messages("missing-docstring", "empty-docstring")
+    @utils.only_required_for_messages("missing-function-docstring", "empty-docstring")
     def visit_functiondef(self, node: nodes.FunctionDef) -> None:
         if self.linter.config.no_docstring_rgx.match(node.name) is None:
             ftype = "method" if node.is_method() else "function"
