@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Configuration file parser class."""
 
@@ -42,15 +42,15 @@ class _ConfigurationFileParser:
         config_content: dict[str, str] = {}
         options: list[str] = []
         for section in parser.sections():
-            if self._ini_file_with_sections(str(file_path)) and not section.startswith(
+            if self._ini_file_with_sections(file_path) and not section.startswith(
                 "pylint"
             ):
                 if section.lower() == "master":
                     # TODO: 3.0: Remove deprecated handling of master, only allow 'pylint.' sections
                     warnings.warn(
                         "The use of 'MASTER' or 'master' as configuration section for pylint "
-                        "has been deprecated, as it's bad practice to not start sections titles with the "
-                        "tool name. Please use 'pylint.main' instead.",
+                        "has been deprecated, as it's bad practice to not start sections titles "
+                        "with the tool name. Please use 'pylint.main' instead.",
                         UserWarning,
                     )
                 else:
@@ -61,11 +61,11 @@ class _ConfigurationFileParser:
         return config_content, options
 
     @staticmethod
-    def _ini_file_with_sections(file_path: str) -> bool:
+    def _ini_file_with_sections(file_path: Path) -> bool:
         """Return whether the file uses sections."""
-        if "setup.cfg" in file_path:
+        if "setup.cfg" in file_path.parts:
             return True
-        if "tox.ini" in file_path:
+        if "tox.ini" in file_path.parts:
             return True
         return False
 
