@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Looks for try/except statements with too much code in the try clause."""
 
@@ -46,7 +46,7 @@ class BroadTryClauseChecker(checkers.BaseChecker):
         ),
     )
 
-    def _count_statements(self, try_node):
+    def _count_statements(self, try_node: nodes.TryExcept | nodes.TryFinally) -> int:
         statement_count = len(try_node.body)
 
         for body_node in try_node.body:
@@ -58,13 +58,15 @@ class BroadTryClauseChecker(checkers.BaseChecker):
     def visit_tryexcept(self, node: nodes.TryExcept | nodes.TryFinally) -> None:
         try_clause_statements = self._count_statements(node)
         if try_clause_statements > self.linter.config.max_try_statements:
-            msg = f"try clause contains {try_clause_statements} statements, expected at most {self.linter.config.max_try_statements}"
+            msg = (
+                f"try clause contains {try_clause_statements} statements, expected at"
+                f" most {self.linter.config.max_try_statements}"
+            )
             self.add_message(
                 "too-many-try-statements", node.lineno, node=node, args=msg
             )
 
-    def visit_tryfinally(self, node: nodes.TryFinally) -> None:
-        self.visit_tryexcept(node)
+    visit_tryfinally = visit_tryexcept
 
 
 def register(linter: PyLinter) -> None:
