@@ -1,27 +1,31 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Looks for comparisons to zero."""
 
 from __future__ import annotations
 
 import itertools
-from collections.abc import Iterable
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING
 
 import astroid
 from astroid import nodes
 
 from pylint import checkers
 from pylint.checkers import utils
+from pylint.interfaces import HIGH
 
 if TYPE_CHECKING:
     from pylint.lint import PyLinter
 
 
-def _is_constant_zero(node):
-    return isinstance(node, astroid.Const) and node.value == 0
+def _is_constant_zero(node: str | nodes.NodeNG) -> bool:
+    # We have to check that node.value is not False because node.value == 0 is True
+    # when node.value is False
+    return (
+        isinstance(node, astroid.Const) and node.value == 0 and node.value is not False
+    )
 
 
 class CompareToZeroChecker(checkers.BaseChecker):
@@ -36,7 +40,7 @@ class CompareToZeroChecker(checkers.BaseChecker):
     name = "compare-to-zero"
     msgs = {
         "C2001": (
-            "Avoid comparisons to zero",
+            '"%s" can be simplified to "%s" as 0 is falsey',
             "compare-to-zero",
             "Used when Pylint detects comparison to a 0 constant.",
         )
@@ -52,26 +56,39 @@ class CompareToZeroChecker(checkers.BaseChecker):
         # while the rest are a list of tuples in node.ops
         # the format of the tuple is ('compare operator sign', node)
         # here we squash everything into `ops` to make it easier for processing later
-        ops = [("", node.left)]
+        ops: list[tuple[str, nodes.NodeNG]] = [("", node.left)]
         ops.extend(node.ops)
-        iter_ops: Iterable[Any] = iter(ops)
-        ops = list(itertools.chain(*iter_ops))
+        iter_ops = iter(ops)
+        all_ops = list(itertools.chain(*iter_ops))
 
-        for ops_idx in range(len(ops) - 2):
-            op_1 = ops[ops_idx]
-            op_2 = ops[ops_idx + 1]
-            op_3 = ops[ops_idx + 2]
+        for ops_idx in range(len(all_ops) - 2):
+            op_1 = all_ops[ops_idx]
+            op_2 = all_ops[ops_idx + 1]
+            op_3 = all_ops[ops_idx + 2]
             error_detected = False
 
             # 0 ?? X
             if _is_constant_zero(op_1) and op_2 in _operators:
                 error_detected = True
+                op = op_3
             # X ?? 0
             elif op_2 in _operators and _is_constant_zero(op_3):
                 error_detected = True
+                op = op_1
 
             if error_detected:
-                self.add_message("compare-to-zero", node=node)
+                original = f"{op_1.as_string()} {op_2} {op_3.as_string()}"
+                suggestion = (
+                    op.as_string()
+                    if op_2 in {"!=", "is not"}
+                    else f"not {op.as_string()}"
+                )
+                self.add_message(
+                    "compare-to-zero",
+                    args=(original, suggestion),
+                    node=node,
+                    confidence=HIGH,
+                )
 
 
 def register(linter: PyLinter) -> None:
