@@ -1,23 +1,22 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Check for if / assign blocks that can be rewritten with if-expressions."""
 
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 from astroid import nodes
 
 from pylint.checkers import BaseChecker
-from pylint.interfaces import IAstroidChecker
 
 if TYPE_CHECKING:
     from pylint.lint import PyLinter
 
 
 class ConsiderTernaryExpressionChecker(BaseChecker):
-
-    __implements__ = (IAstroidChecker,)
     name = "consider_ternary_expression"
     msgs = {
         "W0160": (
@@ -41,7 +40,7 @@ class ConsiderTernaryExpressionChecker(BaseChecker):
         if not isinstance(bst, nodes.Assign) or not isinstance(ost, nodes.Assign):
             return
 
-        for (bname, oname) in zip(bst.targets, ost.targets):
+        for bname, oname in zip(bst.targets, ost.targets):
             if not isinstance(bname, nodes.AssignName) or not isinstance(
                 oname, nodes.AssignName
             ):
@@ -53,5 +52,5 @@ class ConsiderTernaryExpressionChecker(BaseChecker):
         self.add_message("consider-ternary-expression", node=node)
 
 
-def register(linter: "PyLinter") -> None:
+def register(linter: PyLinter) -> None:
     linter.register_checker(ConsiderTernaryExpressionChecker(linter))
