@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Visitor doing some post-processing on the astroid tree.
 
@@ -13,11 +13,12 @@ import collections
 import os
 import traceback
 import warnings
+from abc import ABC, abstractmethod
 from collections.abc import Generator
 from typing import Any, Callable, Optional
 
 import astroid
-from astroid import nodes
+from astroid import nodes, util
 
 from pylint import constants
 from pylint.pyreverse import utils
@@ -49,7 +50,7 @@ def interfaces(node: nodes.ClassDef) -> Generator[Any, None, None]:
     found = set()
     missing = False
     for iface in nodes.unpack_infer(implements):
-        if iface is astroid.Uninferable:
+        if isinstance(iface, util.UninferableBase):
             missing = True
             continue
         if iface not in found:
@@ -123,6 +124,12 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
     * instance_attrs_type
       as locals_type but for klass member attributes (only on astroid.Class)
 
+    * associations_type
+      as instance_attrs_type but for association relationships
+
+    * aggregations_type
+      as instance_attrs_type but for aggregations relationships
+
     * implements,
       list of implemented interface _objects_ (only on astroid.Class nodes)
     """
@@ -134,6 +141,8 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
         self.tag = tag
         # visited project
         self.project = project
+        self.associations_handler = AggregationsHandler()
+        self.associations_handler.set_next(OtherAssociationsHandler())
 
     def visit_project(self, node: Project) -> None:
         """Visit a pyreverse.utils.Project node.
@@ -178,9 +187,12 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
             baseobj.specializations = specializations
         # resolve instance attributes
         node.instance_attrs_type = collections.defaultdict(list)
+        node.aggregations_type = collections.defaultdict(list)
+        node.associations_type = collections.defaultdict(list)
         for assignattrs in tuple(node.instance_attrs.values()):
             for assignattr in assignattrs:
                 if not isinstance(assignattr, nodes.Unknown):
+                    self.associations_handler.handle(assignattr, node)
                     self.handle_assignattr_type(assignattr, node)
         # resolve implemented interface
         try:
@@ -190,9 +202,10 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
                 if node.implements:
                     # TODO: 3.0: Remove support for __implements__
                     warnings.warn(
-                        "pyreverse will drop support for resolving and displaying implemented interfaces in pylint 3.0. "
-                        "The implementation relies on the '__implements__'  attribute proposed in PEP 245, which was rejected "
-                        "in 2006.",
+                        "pyreverse will drop support for resolving and displaying "
+                        "implemented interfaces in pylint 3.0. The implementation "
+                        "relies on the '__implements__'  attribute proposed in PEP 245"
+                        ", which was rejected in 2006.",
                         DeprecationWarning,
                     )
             else:
@@ -287,14 +300,14 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
             if fullname != basename:
                 self._imported_module(node, fullname, relative)
 
-    def compute_module(self, context_name: str, mod_path: str) -> int:
-        """Return true if the module should be added to dependencies."""
+    def compute_module(self, context_name: str, mod_path: str) -> bool:
+        """Should the module be added to dependencies ?"""
         package_dir = os.path.dirname(self.project.path)
         if context_name == mod_path:
-            return 0
-        if astroid.modutils.is_standard_module(mod_path, (package_dir,)):
-            return 1
-        return 0
+            return False
+        # astroid does return a boolean but is not typed correctly yet
+
+        return astroid.modutils.module_in_path(mod_path, (package_dir,))  # type: ignore[no-any-return]
 
     def _imported_module(
         self, node: nodes.Import | nodes.ImportFrom, mod_path: str, relative: bool
@@ -313,6 +326,63 @@ class Linker(IdGeneratorMixIn, utils.LocalsVisitor):
                 mod_paths.append(mod_path)
 
 
+class AssociationHandlerInterface(ABC):
+    @abstractmethod
+    def set_next(
+        self, handler: AssociationHandlerInterface
+    ) -> AssociationHandlerInterface:
+        pass
+
+    @abstractmethod
+    def handle(self, node: nodes.AssignAttr, parent: nodes.ClassDef) -> None:
+        pass
+
+
+class AbstractAssociationHandler(AssociationHandlerInterface):
+    """
+    Chain of Responsibility for handling types of association, useful
+    to expand in the future if we want to add more distinct associations.
+
+    Every link of the chain checks if it's a certain type of association.
+    If no association is found it's set as a generic association in `associations_type`.
+
+    The default chaining behavior is implemented inside the base handler
+    class.
+    """
+
+    _next_handler: AssociationHandlerInterface
+
+    def set_next(
+        self, handler: AssociationHandlerInterface
+    ) -> AssociationHandlerInterface:
+        self._next_handler = handler
+        return handler
+
+    @abstractmethod
+    def handle(self, node: nodes.AssignAttr, parent: nodes.ClassDef) -> None:
+        if self._next_handler:
+            self._next_handler.handle(node, parent)
+
+
+class AggregationsHandler(AbstractAssociationHandler):
+    def handle(self, node: nodes.AssignAttr, parent: nodes.ClassDef) -> None:
+        if isinstance(node.parent, (nodes.AnnAssign, nodes.Assign)) and isinstance(
+            node.parent.value, astroid.node_classes.Name
+        ):
+            current = set(parent.aggregations_type[node.attrname])
+            parent.aggregations_type[node.attrname] = list(
+                current | utils.infer_node(node)
+            )
+        else:
+            super().handle(node, parent)
+
+
+class OtherAssociationsHandler(AbstractAssociationHandler):
+    def handle(self, node: nodes.AssignAttr, parent: nodes.ClassDef) -> None:
+        current = set(parent.associations_type[node.attrname])
+        parent.associations_type[node.attrname] = list(current | utils.infer_node(node))
+
+
 def project_from_files(
     files: list[str],
     func_wrapper: _WrapperFuncT = _astroid_wrapper,
