@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Generic classes/functions for pyreverse core/extensions."""
 
@@ -74,12 +74,12 @@ def get_visibility(name: str) -> str:
 
 def is_interface(node: nodes.ClassDef) -> bool:
     # bw compatibility
-    return node.type == "interface"
+    return node.type == "interface"  # type: ignore[no-any-return]
 
 
 def is_exception(node: nodes.ClassDef) -> bool:
     # bw compatibility
-    return node.type == "exception"
+    return node.type == "exception"  # type: ignore[no-any-return]
 
 
 # Helpers #####################################################################
@@ -170,9 +170,9 @@ class LocalsVisitor:
 
 def get_annotation_label(ann: nodes.Name | nodes.NodeNG) -> str:
     if isinstance(ann, nodes.Name) and ann.name is not None:
-        return ann.name
+        return ann.name  # type: ignore[no-any-return]
     if isinstance(ann, nodes.NodeNG):
-        return ann.as_string()
+        return ann.as_string()  # type: ignore[no-any-return]
     return ""
 
 
@@ -199,14 +199,22 @@ def get_annotation(
         default = ""
 
     label = get_annotation_label(ann)
-    if ann:
-        label = (
-            rf"Optional[{label}]"
-            if getattr(default, "value", "value") is None
-            and not label.startswith("Optional")
-            else label
+
+    if (
+        ann
+        and getattr(default, "value", "value") is None
+        and not label.startswith("Optional")
+        and (
+            not isinstance(ann, nodes.BinOp)
+            or not any(
+                isinstance(child, nodes.Const) and child.value is None
+                for child in ann.get_children()
+            )
         )
-    if label:
+    ):
+        label = rf"Optional[{label}]"
+
+    if label and ann:
         ann.name = label
     return ann
 
