@@ -1,8 +1,8 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
-"""Functions to generate files readable with Georg Sander's vcg
+"""Functions to generate files readable with George Sander's vcg
 (Visualization of Compiler Graphs).
 
 You can download vcg at https://rw4.cs.uni-sb.de/~sander/html/gshome.html
@@ -10,7 +10,11 @@ Note that vcg exists as a debian package.
 See vcg's documentation for explanation about the different values that
 maybe used for the functions parameters.
 """
-from typing import Any, Dict, Mapping, Optional
+
+from __future__ import annotations
+
+from collections.abc import Mapping
+from typing import Any
 
 from pylint.pyreverse.printer import EdgeType, Layout, NodeProperties, NodeType, Printer
 
@@ -145,27 +149,41 @@ EDGE_ATTRS = {
     "anchor": 1,
     "horizontal_order": 1,
 }
-SHAPES: Dict[NodeType, str] = {
+SHAPES: dict[NodeType, str] = {
     NodeType.PACKAGE: "box",
     NodeType.CLASS: "box",
     NodeType.INTERFACE: "ellipse",
 }
-ARROWS: Dict[EdgeType, Dict] = {
-    EdgeType.USES: dict(arrowstyle="solid", backarrowstyle="none", backarrowsize=0),
-    EdgeType.INHERITS: dict(
-        arrowstyle="solid", backarrowstyle="none", backarrowsize=10
-    ),
-    EdgeType.IMPLEMENTS: dict(
-        arrowstyle="solid",
-        backarrowstyle="none",
-        linestyle="dotted",
-        backarrowsize=10,
-    ),
-    EdgeType.ASSOCIATION: dict(
-        arrowstyle="solid", backarrowstyle="none", textcolor="green"
-    ),
+# pylint: disable-next=consider-using-namedtuple-or-dataclass
+ARROWS: dict[EdgeType, dict[str, str | int]] = {
+    EdgeType.USES: {
+        "arrowstyle": "solid",
+        "backarrowstyle": "none",
+        "backarrowsize": 0,
+    },
+    EdgeType.INHERITS: {
+        "arrowstyle": "solid",
+        "backarrowstyle": "none",
+        "backarrowsize": 10,
+    },
+    EdgeType.IMPLEMENTS: {
+        "arrowstyle": "solid",
+        "backarrowstyle": "none",
+        "linestyle": "dotted",
+        "backarrowsize": 10,
+    },
+    EdgeType.ASSOCIATION: {
+        "arrowstyle": "solid",
+        "backarrowstyle": "none",
+        "textcolor": "green",
+    },
+    EdgeType.AGGREGATION: {
+        "arrowstyle": "solid",
+        "backarrowstyle": "none",
+        "textcolor": "green",
+    },
 }
-ORIENTATION: Dict[Layout, str] = {
+ORIENTATION: dict[Layout, str] = {
     Layout.LEFT_TO_RIGHT: "left_to_right",
     Layout.RIGHT_TO_LEFT: "right_to_left",
     Layout.TOP_TO_BOTTOM: "top_to_bottom",
@@ -200,7 +218,7 @@ class VCGPrinter(Printer):
         self,
         name: str,
         type_: NodeType,
-        properties: Optional[NodeProperties] = None,
+        properties: NodeProperties | None = None,
     ) -> None:
         """Create a new node.
 
@@ -245,7 +263,7 @@ class VCGPrinter(Printer):
         from_node: str,
         to_node: str,
         type_: EdgeType,
-        label: Optional[str] = None,
+        label: str | None = None,
     ) -> None:
         """Create an edge from one node to another to display relationships."""
         self.emit(
@@ -261,13 +279,15 @@ class VCGPrinter(Printer):
         )
         self.emit("}")
 
-    def _write_attributes(self, attributes_dict: Mapping[str, Any], **args) -> None:
+    def _write_attributes(
+        self, attributes_dict: Mapping[str, Any], **args: Any
+    ) -> None:
         """Write graph, node or edge attributes."""
         for key, value in args.items():
             try:
                 _type = attributes_dict[key]
             except KeyError as e:
-                raise Exception(
+                raise AttributeError(
                     f"no such attribute {key}\npossible attributes are {attributes_dict.keys()}"
                 ) from e
 
@@ -278,6 +298,6 @@ class VCGPrinter(Printer):
             elif value in _type:
                 self.emit(f"{key}:{value}\n")
             else:
-                raise Exception(
+                raise ValueError(
                     f"value {value} isn't correct for attribute {key} correct values are {type}"
                 )
