@@ -1,6 +1,6 @@
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/pylint/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/pylint/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/pylint/blob/main/CONTRIBUTORS.txt
 
 """Plain text reporters:.
 
@@ -133,7 +133,8 @@ def colorize_ansi(
     # TODO: 3.0: Remove deprecated typing and only accept MessageStyle as parameter
     if not isinstance(msg_style, MessageStyle):
         warnings.warn(
-            "In pylint 3.0, the colorize_ansi function of Text reporters will only accept a MessageStyle parameter",
+            "In pylint 3.0, the colorize_ansi function of Text reporters will only accept a "
+            "MessageStyle parameter",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -273,12 +274,14 @@ class ColorizedTextReporter(TextReporter):
         ) = None,
     ) -> None:
         super().__init__(output)
-        # TODO: 3.0: Remove deprecated typing and only accept ColorMappingDict as color_mapping parameter
+        # TODO: 3.0: Remove deprecated typing and only accept ColorMappingDict as
+        #  color_mapping parameter
         if color_mapping and not isinstance(
             list(color_mapping.values())[0], MessageStyle
         ):
             warnings.warn(
-                "In pylint 3.0, the ColorizedTextReporter will only accept ColorMappingDict as color_mapping parameter",
+                "In pylint 3.0, the ColorizedTextReporter will only accept ColorMappingDict as "
+                "color_mapping parameter",
                 DeprecationWarning,
                 stacklevel=2,
             )
