@@ -14,6 +14,7 @@ from pylint.utils.utils import (
     HAS_ISORT_5,
     IsortDriver,
     _check_csv,
+    _check_regexp_csv,
     _format_option_value,
     _splitstrip,
     _unquote,
@@ -34,6 +35,7 @@ __all__ = [
     "HAS_ISORT_5",
     "IsortDriver",
     "_check_csv",
+    "_check_regexp_csv",
     "_format_option_value",
     "_splitstrip",
     "_unquote",
